@@ -39,6 +39,37 @@ sub test_OPTIONS : Path('foobar') {
     $c->res->body('OPTIONS');
 }
 
+sub other_test :Local :ActionClass('+Catalyst::Action::REST') {
+    my ( $self, $c ) = @_;
+    $c->res->header('X-Was-In-TopLevel', 1);
+}
+
+sub other_test_GET {
+    my ( $self, $c ) = @_;
+    $c->res->body('GET');
+}
+
+sub other_test_POST {
+    my ( $self, $c ) = @_;
+    $c->res->body('POST');
+}
+
+sub other_test_PUT :ActionClass('+Test::Action::Class::Sub') {
+    my ( $self, $c ) = @_;
+    $c->res->body('PUT');
+}
+
+sub other_test_DELETE {
+    my ( $self, $c ) = @_;
+    $c->res->body('DELETE');
+}
+
+sub other_test_OPTIONS {
+    my ( $self, $c ) = @_;
+
+    $c->res->body('OPTIONS');
+}
+
 sub end : Private {} # Don't need serialization..
 
 1;
